local L = LibStub("AceLocale-3.0"):GetLocale("HotLoot")

local unitTable = {
	["rare"] = "Rare",
	["boss"] = "Boss",
	["chest"] = "Chest",
	["unitKeyword"] = "Unit Keyword"
}

local closeKeyTable = {
	["0"] = "None",
	["ctrl"] = "Control",
	["shift"] = "Shift",
	["alt"] = "Alt"
}

local growthDirectionTable = {
	[1] = L["Up"],
	[-1] = L["Down"]
}

-- SetTextSide
local textSideTable = {
	[0] = L["Right"],
	[1] = L["Left"]
}

local itemTypeTable = {
	["0None"] = L["None"],
	["Quest"] = L["Quest Items"],
	["Junk"] = L["Junk"],
	["Gem"] = L["Gems"],
	["Metal & Stone"] = L["Metal & Stone"],
	["Cooking Ingredient"] = L["Cooking Ingredients"],
	["Herb"] = L["Herbs"],
	["Leather"] = L["Leather"],
	["Cloth"] = L["Cloth"],
	["Elemental"] = L["Elementals"],
	["Enchanting"] = L["Enchanting"],
	["Potion"] = L["Potions"],
	["Flask"] = L["Flasks"],
	["Elixir"] = L["Elixirs"],
	["z1Poor"] = "|cff9d9d9d"..L["Poor"].."|r",
	["z2Common"] = "|cffffffff"..L["Common"].."|r",
	["z3Uncommon"] = "|cff1eff00"..L["Uncommon"].."|r",
	["z4Rare"] = "|cff0070dd"..L["Rare"].."|r",
	["z5Epic"] = "|cffa335ee"..L["Epic"].."|r",
	["z6Legendary"] = "|cffff8000"..L["Legendary"].."|r",
	["Include"] = L["Include List"],
}

local themeTable = {
	["classic"] = "Classic",
	--["minimal"] = "Minimal",
	--["holo"] = "Holo",
	--["glow"] = "Glow",
	["color"] = "Colored",
}
-- options
 hlOptions = {
    name = "HotLoot",
    handler = HotLoot,
    type = "group",
	childGroups = "tree",
    args = {
		lootDesc = {
			name = L["lootDesc"],			
			type = "description",
			order = 0
		},
		lootDesc3 = {
			name = L["lootDesc3"],  
			type = "description",
			order = 2
		},
		enable = {
			name = L["EnableName"],
			desc = L["EnableDesc"],
			type = "toggle",
			set = "SetLootEnabled",
			get = "GetLootEnabled",
			hidden = true
		},
		debug = {
			name = L["DebugName"],
			desc = L["DebugDesc"],
			type = "toggle",
			set = "SetLootDebug",
			get = "GetLootDebug",
			hidden = true
		},
		autoclose = {
			name = L["ACEnableName"],
			desc = L["ACEnableDesc"],
			type = "toggle",
			set = "SetLootClose",
			get = "GetLootClose",
			hidden = true
		},
		skinmode = {
			name = "Enable",
			desc = "Skinning mode will pick up and delete any items left over after autolooting.\n|cFFFF0000(WARNING: use with caution this deletes items. HL is not responsible for lost items.)",
			type = "toggle",
			set = "SetLootSkinMode",
			get = "GetLootSkinMode",
			confirm = true,
			hidden = true
		},
		monitor = {
			name = "Enable Loot Monitor",
			type = "toggle",
			set = "SetLootEnableMonitor",
			get = "GetLootEnableMonitor",
			hidden = true
		},
		groupSystem = {
			name = "System",
			type = "group",
			order = 4,
			
			args = {
				lootEnabled = {
					name = L["EnableName"],
					desc = L["EnableDesc"],
					type = "toggle",
					set = "SetLootEnabled",
					get = "GetLootEnabled",
					order = 1
				},
				lootDebug = {
					name = L["DebugName"],
					desc = L["DebugDesc"],
					type = "toggle",
					set = "SetLootDebug",
					get = "GetLootDebug",
					hidden = "Advanced",
					order = 5
				},
				lootAnnounce = {
					name = L["AnnounceName"],
					desc = L["AnnounceDesc"],
					type = "toggle",
					set = "SetLootAnnounce",
					get = "GetLootAnnounce",
					order = 3
				},
				lootMinimap = {
					name = L["HideMMName"],
					desc = L["HideMMDesc"],
					type = "toggle",
					set = "SetMinimap",
					get = "GetMinimap",
					order = 2
				},
				lootAdvanced = {
					name = L["AdvancedName"],
					desc = L["AdvancedDesc"],
					type = "toggle",
					set = "SetLootAdvanced",
					get = "GetLootAdvanced",
					order = 4
				},
				groupLWindow = {
					name = L["ACGroup"],
					type = "group",
					order = 50,
					inline = true,
					args = {
						lootClose = {
							name = L["ACEnableName"],
							desc = L["ACEnableDesc"],
							type = "toggle",
							set = "SetLootClose",
							get = "GetLootClose",
							order = 1
						},
						lootCloseKey = {
							name = L["ACKeyName"],
							desc = L["ACKeyDesc"],
							type = "select",
							values = closeKeyTable,
							set = "SetLootCloseKey",
							get = "GetLootCloseKey",
							order = 2
						},
					},
				},
				groupSkinning = {
					name = L["SkinningGroup"],
					type = "group",
					order = 100,
					inline = true,
					--hidden = "Advanced",
					args = {
						lootSkinKey = {
							name = L["SkinningKeyName"],
							desc = L["SkinningKeyDesc"],
							type = "select",
							values = closeKeyTable,
							set = "SetLootSkinKey",
							get = "GetLootSkinKey",
							order = 2
						},
						skinmode = {
							name = L["SkinningEnableName"],
							desc = L["SkinningEnableDesc"],
							type = "toggle",
							set = "SetLootSkinMode",
							get = "GetLootSkinMode",
							confirm = true,
							order = 1
						},
					},
				},
			}, 
		},
		goupLootMonitor = {
			name = L["LootMonGroup"], 
			type = "group", 
			order = 5, 
			childGroups = "tab",
			args = {
				goupLootMonitor1 = {
				name = L["GeneralGroup"], 
				type = "group", 
				order = 5, 
				args = {
				lootEnableMonitor = {
					name = L["LootMonName"],
					desc = L["LootMonDesc"],
					type = "toggle",
					set = "SetLootEnableMonitor",
					get = "GetLootEnableMonitor",
					width = "double",
					order = 1
				},
				lootShowAnchor = {
					name = L["ShowAnchName"],
					desc = L["ShowAnchDesc"],
					type = "toggle",
					set = "SetLootShowAnchor",
					get = "GetLootShowAnchor",
					width = "double",
					order = 2
				},
				lootShowNames = {
					name = L["ShowNamesName"],
					desc = L["ShowNamesDesc"],
					type = "toggle",
					set = "SetLootShowNames",
					get = "GetLootShowNames",
					disabled = "ToggleNamesDisable",
					hidden = "Advanced",
					width = "double",
					order = 3
				},
				lootShowQuantities = {
					name = L["ShowQuantName"],
					desc = L["ShowQuantDesc"],
					type = "toggle",
					set = "SetLootShowQuantities",
					get = "GetLootShowQuantities",
					width = "double",
					order = 4
				},
				inlineQuant = {
					name = L["InlineQuantName"],
					desc = L["InlineQuantDesc"],
					type = "toggle",
					set = "SetInlineQuant",
					get = "GetInlineQuant",
					hidden = "Advanced",
					width = "double",
					order = 5
				},
				lootShowTotal = {
					name = L["ShowTotName"],
					desc = L["ShowTotDesc"],
					type = "toggle",
					set = "SetShowTotal",
					get = "GetShowTotal",
					width = "double",
					order = 6
				},
				groupGridMode = {
					name = L["GridModeGroup"],
					type = "group",
					order = 15,
					inline = true,
					hidden = true,
					--hidden = "Advanced",
					disabled = "ToggleGridDisable",
					args = {
						lootGridMode = {
							name = L["GridEnableName"],
							desc = L["GridEnableDesc"],
							type = "toggle",
							set = "SetLootGridMode",
							get = "GetLootGridMode",
							order = 1
						},
						lootGridNumColumns = {
							name = L["GridColName"],
							type = "range",
							min = 1,
							max = 10,
							step = 1, 
							bigStep = 1,
							set = "SetLootGridNumColumns",
							get = "GetLootGridNumColumns",
							order = 2
						},
					},
				},
				}},
				goupLootMonitor2 = {
				name = L["Appearance"], 
				type = "group", 
				order = 6, 
				args = {
				lootIconSize = {
					name = L["IconSizeName"],
					desc = L["IconSizeDesc"],
					type = "range",
					min = 8,
					max = 32,
					step = 8, 
					bigStep = 8,
					disabled = "ToggleSizeDisable",
					set = "SetLootIconSize",
					get = "GetLootIconSize",
					hidden = "Advanced",
					order = 7
				},
				lootTransparency = {
					name = L["TransName"],
					desc = L["TransDesc"],
					type = "range",
					min = 0,
					max = 1,
					step = 0.1, 
					bigStep = 0.1,
					set = "SetLootTrans",
					get = "GetLootTrans",
					--hidden = "Advanced",
					order = 8
				},
				lootGrowthDirection = {
					name = L["GrowthDircName"],
					desc = L["GrowthDircDesc"],
					type = "select",
					values = growthDirectionTable,
					set = "SetLootGrowthDirection",
					get = "GetLootGrowthDirection",
					order = 9
				},
				textSide = {
					name = L["TxtSideName"],
					desc = L["TxtSideDesc"],
					type = "select",
					values = textSideTable,
					set = "SetTextSide",
					get = "GetTextSide",
					order = 10
				},
				
				themeSelect = {
					name = L["ThemeSelName"],
					desc = L["ThemeSelDesc"],
					type = "select",
					values = themeTable,
					set = "SetThemeSelect",
					get = "GetThemeSelect",
					--disabled = true,
					order = 11
				},
				colorQual = {
					name = L["ColorQualName"],
					desc = L["ColorQualDesc"],
					type = "toggle",
					set = "SetColorQual",
					get = "GetColorQual",
					hidden = "ColorHide",
					--disabled = true,
					order = 12
				},
				themeColorSelect = {
					name = L["ThemeColorSelect"],
					--desc = L["ThemeSelDesc"],
					type = "color",
					set = "SetThemeColorSelect",
					get = "GetThemeColorSelect",
					hidden = "ColorHide",
					hasAlpha = true,
					--disabled = true,
					order = 13
				},
				themeColorBorderSelect = {
					name = L["ThemeColorBorderSelect"],
					--desc = L["ThemeSelDesc"],
					type = "color",
					set = "SetThemeColorBorderSelect",
					get = "GetThemeColorBorderSelect",
					hidden = "ColorHide",
					hasAlpha = true,
					--disabled = true,
					order = 14
				},
				minWidth = {
					name = L["MinWidthName"],
					desc = L["MinWidthDesc"],
					type = "input",
					--width = "half",
					set = "SetMinWidth",
					get = "GetMinWidth",
					order = 15
				},
				initialDelay = {
					name = L["InitDelayName"],
					desc = L["InitDelayDesc"],
					type = "range",
					min = 1,
					max = 10,
					step = 1, 
					bigStep = 1,
					--width = "half",
					set = "SetIDelay",
					get = "GetIDelay",
					hidden = "Advanced",
					order = 16
				},
				secondaryDelay = {
					name = L["SecDelayName"],
					desc = L["SecDelayDesc"],
					type = "range",
					min = 1,
					max = 10,
					step = 1, 
					bigStep = 1,
					--width = "half",
					set = "SetSDelay",
					get = "GetSDelay",
					hidden = "Advanced",
					order = 17
				},
				fadeSpeed = {
					name = L["FadeDelayName"],
					desc = L["FadeDelayDesc"],
					type = "range",
					min = 1,
					max = 10,
					step = 1, 
					bigStep = 1,
					hidden = "Advanced",
					set = "SetFSpeed",
					get = "GetFSpeed",
					order = 18
				},
				
				}},
				lootTestMonitor = {
							name = L["TestMonName"],
							--desc = " ",
							type = "execute",
							func = "TestMonitor", 
							order = 30
						},
						lootResetMonitor = {
							name = L["ResetMonName"],
							--desc = " ",
							type = "execute",
							func = "ResetMonitor", 
							order = 31
				},
				lootDesc = {
					name = L["MonDescName"],
					type = "description",
					hidden = true,
					order = 65,
				},
			}, 
		},
		groupFilters = {
			name = L["FilterGroup"],
			type = "group",
			order = 6,
			args = {
				groupGeneral = {
					name = L["GeneralGroup"],
					type = "group",
					order = 1,
					inline = true,
					args = {
				lootGold = {
					name = L["GoldFilterName"],
					desc = L["GoldFilterDesc"],
					type = "toggle",
					set = "SetLootGold",
					get = "GetLootGold",
					order = 1
				},
				lootCurrency = {
					name = L["CurrFilterName"],
					desc = L["CurrFilterDesc"],
					type = "toggle",
					set = "SetLootCurrency",
					get = "GetLootCurrency",
					order = 2
				},
				lootQuest = {
					name = L["QuestFilterName"],
					desc = L["QuestFilterDesc"],
					type = "toggle",
					set = "SetLootQuest",
					get = "GetLootQuest",
					order = 3
				},
				lootJunk = {
					name = L["JunkFilterName"], 
					desc = L["JunkFilterDesc"],
					type = "toggle",
					set = "SetLootJunk",
					get = "GetLootJunk",
					order = 4
				},
				--[[
				lootPick = {
					name = "Loot Pickpocket", 
					desc = "Check to autoloot while pickpocketing.\n(for rogues)",
					type = "toggle",
					set = "SetLootJunk",
					get = "GetLootJunk",
					order = 5
				},]]
			},
		},
		groupProfessions = {
			name = L["ProfessionsGroup"],
			type = "group",
			order = 2,
			inline = true,
			args = {
				lootCloth = {
					name = L["ClothFilterName"],
					desc = L["ClothFilterDesc"],
					type = "toggle",
					set = "SetLootCloth",
					get = "GetLootCloth",
					order = 0
				},
				lootMining = {
					name = L["OreFilterName"],
					desc = L["OreFilterDesc"],
					type = "toggle",
					set = "SetLootMining",
					get = "GetLootMining",
					order = 1
				},
				lootGems = {
					name = L["GemFilterName"],
					desc = L["GemFilterDesc"],
					type = "toggle",
					set = "SetLootGems",
					get = "GetLootGems",
					order = 2
				},
				lootHerbs = {
					name = L["HerbFilterName"],
					desc = L["HerbFilterDesc"],
					type = "toggle",
					set = "SetLootHerbs",
					get = "GetLootHerbs",
					order = 3
				},
				lootSkinning = {
					name = L["LeatherFilterName"],
					desc = L["LeatherFilterDesc"],
					type = "toggle",
					set = "SetLootSkinning",
					get = "GetLootSkinning",
					order = 4
				},
				lootFishing = {
					name = L["FishingFilterName"],
					desc = L["FishingFilterDesc"],
					type = "toggle",
					set = "SetLootFishing",
					get = "GetLootFishing",
					order = 5
				},
				lootEnchanting = {
					name = L["EnchantingFilterName"],
					desc = L["EnchantingFilterDesc"],
					type = "toggle",
					set = "SetLootEnchanting",
					get = "GetLootEnchanting",
					order = 6
				},
				lootCooking = {
					name = L["CookingFilterName"],
					desc = L["CookingFilterDesc"],
					--\n\n|cff1eff00Note: Blizzard has cooking ingredients spread all over different categories but this should get most of them.|r
					type = "toggle",
					set = "SetLootCooking",
					get = "GetLootCooking",
					width = "full",
					order = 9
				},
				lootRecipes = {
					name = L["RecipeFilterName"],
					desc = L["RecipeFilterDesc"],
					type = "toggle",
					set = "SetLootRecipes",
					get = "GetLootRecipes",
					order = 10
				},
			}
		},
		groupDrops = {
			name = L["DropsGroup"],
			type = "group",
			order = 3,
			inline = true,
			args = {
				lootPots = {
					name = L["PotionFilterName"],
					desc = L["PotionFilterDesc"],
					type = "toggle",
					set = "SetLootPots",
					get = "GetLootPots",
					order = 2
				},
				lootFlasks = {
					name = L["FlaskFilterName"],
					desc = L["FlaskFilterDesc"],
					type = "toggle",
					set = "SetLootFlasks",
					get = "GetLootFlasks",
					order = 3
				},
				lootElixirs = {
					name = L["ElixirFilterName"],
					desc = L["ElixirFilterDesc"],
					type = "toggle",
					set = "SetLootElixirs",
					get = "GetLootElixirs",
					order = 4
				},
				lootMoH = {
					name = L["MoHFilterName"],
					desc = L["MoHFilterDesc"],
					type = "toggle",
					set = "SetLootMoH",
					get = "GetLootMoH",
					width = "double",
					order = 6
				},
				lootElemental = {
					name = L["EleFilterName"],
					desc = L["EleFilterDesc"],
					type = "toggle",
					set = "SetLootElemental",
					get = "GetLootElemental",
					order = 5
				},	
			},
		},
		},
		},
		groupTimeless = {
			name = L["TimelessIsleGroup"],
			type = "group",
			order = 9,
			args = {
				timelessDesc1 = {
					name = L["TimelessIsleDesc"],			
					type = "description",
					order = 0,
				},
				groupTBuffs = {
					name = L["BuffItemsGroup"],
					type = "group",
					order = 1,
					inline = true,
					args = {
						lootBotA = {
							name = L["BoAFilterName"],
							desc = L["BoAFilterDesc"],
							type = "toggle",
							set = "SetLootBotA",
							get = "GetLootBotA",
							width = "double",
							order = 2,
						},
						lootDoEM = {
							name = L["DoEMFilterName"],
							desc = L["DoEMFilterDesc"],
							type = "toggle",
							set = "SetLootDoEM",
							get = "GetLootDoEM",
							width = "double",
							order = 3,
						},
						lootSC = {
							name = L["SCFilterName"],
							desc = L["SCFilterDesc"],
							type = "toggle",
							set = "SetLootSC",
							get = "GetLootSC",
							width = "double",
							order = 4,
						},
					},
				},
				groupTRep = {
					name = L["RepGroup"],
					type = "group",
					order = 2,
					inline = true,
					args = {
						lootRepMeat = {
							name = L["RepMeatFilterName"],
							desc = L["RepMeatFilterDesc"],
							type = "toggle",
							set = "SetLootRepMeat",
							get = "GetLootRepMeat",
							width = "double",
							order = 1,
						},
					},
				},
			},
		},
		groupQuality = {
			name = L["ItemQualityGroup"],
			type = "group",
			order = 9,
			args = {
				magicDesc1 = {
					name = L["ItemQualityDesc"],
					type = "description",
					order = 1,
				},
				lootPoor = {
					name = L["PoorFilterName"],
					desc = L["PoorFilterDesc"],
					type = "toggle",
					set = "SetLootPoor",
					get = "GetLootPoor",
					width = "full",
					order = 2,
				},
				spacerQ1 = {
					name = "",			
					type = "description",
					order = 3,
				},
				lootCommon = {
					name = L["CommonFilterName"],
					desc = L["CommonFilterDesc"],
					type = "toggle",
					set = "SetLootCommon",
					get = "GetLootCommon",
					width = "full",
					order = 4,
				},
				spacerQ2 = {
					name = "",			
					type = "description",
					order = 5,
				},
				lootUncommon = {
					name = L["UncommonFilterName"],
					desc = L["UncommonFilterDesc"],
					type = "toggle",
					set = "SetLootUncommon",
					get = "GetLootUncommon",
					order = 6,
					width = "full",
				},	
				spacerQ3 = {
					name = "",			
					type = "description",
					order = 7,
				},
				lootRare = {
					name = L["RareFilterName"],
					desc = L["RareFilterDesc"],
					type = "toggle",
					set = "SetLootRare",
					get = "GetLootRare",
					width = "full",
					order = 8,
				},
				spacerQ4 = {
					name = "",			
					type = "description",
					order = 9,
				},
				lootEpic = {
					name = L["EpicFilterName"],
					desc = L["EpicFilterDesc"],
					type = "toggle",
					set = "SetLootEpic",
					get = "GetLootEpic",
					width = "full",
					order = 10,
				},
				spacerQ5 = {
					name = "",			
					type = "description",
					order = 11,
				},
				lootLegendary = {
					name = L["LegendaryFilterName"],
					desc = L["LegendaryFilterDesc"],
					type = "toggle",
					set = "SetLootLegendary",
					get = "GetLootLegendary",
					width = "full",
					order = 12,
				},
			},
		},
		groupInclude = {
			name = L["InExGroup"],
			type = "group",
			order = 11,
			args = {
				includeHeader = {
					name = L["IncludeHeader"],
					type = "header",
					order = 0,
				},
				includeDrop = {
					name = L["IncludeListName"],
					type = "select",
					set = "SetIncludeDrop",
					get = "GetIncludeDrop",
					values = iList,
					order = 1,
				},
				includeList = {
					name = L["IncludeInputName"],
					--multiline = 10,
					type = "input",
					set = "SetIncludeList",
					get = "GetIncludeList",
					--width = "full",
					order = 2
				},
				includeRemove = {
					name = L["IncludeRemoveName"],
					type = "execute",
					func = RemoveIList,
					order = 3,
				},
				excludeHeader = {
					name = L["ExcludeHeader"],
					type = "header",
					order = 4,
				},
				excludeDrop = {
					name = L["ExcludeListName"],
					type = "select",
					set = "SetExcludeDrop",
					get = "GetExcludeDrop",
					values = eList,
					order = 5,
				},
				excludeList = {
					name = L["ExcludeInputName"],
					--multiline = 10,
					type = "input",
					set = "SetExcludeList",
					get = "GetExcludeList",
					--width = "full",
					order = 6
				},
				excludeRemove = {
					name = L["ExcludeRemoveName"],
					type = "execute",
					func = RemoveEList,
					order = 7,
				},
			},
		},
		groupThresholds = {
			name = L["ThreshGroup"],
			type = "group",
			order = 13,
			args = {
				lootDesc = {
					name = "See the help section for details.\n",
					type = "description",
					order = 0
				},
				groupT1 = {
					name = L["Thresh1Group"],
					type = "group",
					order = 1,
					inline = true,
					args = {
						type1 = {
							name = L["Thresh1TypeName"],
							desc = L["Thresh1TypeDesc"],
							type = "select",
							values = itemTypeTable,
							set = "SetType1",
							get = "GetType1",
							order = 2
						},
						value1 = {
							name = L["Thresh1ValueName"],
							type = "input",
							set = "SetValue1",
							get = "GetValue1",
							--pattern = "(%d?%d)[gsc]",
							pattern = "(%d?%d?)[gsc]?%s*(%d?%d?)[gsc]?%s*(%d?%d)[gsc]",
							usage = L["Thresh1ValueDesc"],
							--usage = "Value is entered in gold.",
							--width = "full",
							order = 3
						},
					},
				},
				groupT2 = {
					name = L["Thresh2Group"],
					type = "group",
					order = 2,
					inline = true,
					args = {
						type2 = {
							name = L["Thresh2TypeName"],
							desc = L["Thresh2TypeDesc"],
							type = "select",
							values = itemTypeTable,
							set = "SetType2",
							get = "GetType2",
							order = 5
						},
						value2 = {
							name = L["Thresh2ValueName"],
							type = "input",
							set = "SetValue2",
							get = "GetValue2",
							--pattern = "(%d+)",
							pattern = "(%d?%d?)[gsc]?%s*(%d?%d?)[gsc]?%s*(%d?%d)[gsc]",
							usage = L["Thresh2ValueDesc"],
							--usage = "Value is entered in gold.",
							--width = "full",
							order = 6
						},
					},
				},
				groupT3 = {
					name = L["Thresh3Group"],
					type = "group",
					order = 3,
					inline = true,
					args = {
						type3 = {
							name = L["Thresh3TypeName"],
							desc = L["Thresh3TypeDesc"],
							type = "select",
							values = itemTypeTable,
							set = "SetType3",
							get = "GetType3",
							order = 8
						},
						value3 = {
							name = L["Thresh3ValueName"],
							type = "input",
							set = "SetValue3",
							get = "GetValue3",
							--pattern = "(%d+)",
							pattern = "(%d?%d?)[gsc]?%s*(%d?%d?)[gsc]?%s*(%d?%d)[gsc]",
							usage = L["Thresh3ValueDesc"],
							--usage = "Value is entered in gold.",
							--width = "full",
							order = 9
						},
					},
				},
				useQuant = {
					name = L["UseQuantValName"],
					desc = L["UseQuantValDesc"],
					type = "toggle",
					set = "SetUseQuant",
					get = "GetUseQuant",
					hidden = "Advanced",
					order = 10
				},
			},
		},
		groupUnit = {
			name = "Unit Filter",
			type = "group",
			order = 14,
			disabled = false,
			hidden = true,
			args = {
				unitEnable = {
					name = "Enable",
					desc = "Skinning mode will pick up and delete any items left over after autolooting.\n|cFFFF0000(WARNING: use with caution this deletes items. HL is not responsible for lost items.)",
					type = "toggle",
					set = "SetUnitEnable",
					get = "GetUnitEnable",
					order = 0
				},
				typeSelect = {
					name = "Unit Select",
					desc = "Here you can choose the modifier key to temporarily disable auto closing the loot window if it is enabled.",
					type = "multiselect",
					values = unitTable,
					set = "SetTypeSelect",
					get = "GetTypeSelect",
					order = 1
				},
				unitKeyword = {
					name = "Unit Keyword",
					desc = "Here you can choose the modifier key to temporarily enable Skinning Mode.",
					type = "input",
					set = "SetUnitKeyword",
					get = "GetUnitKeyword",
					hidden = "ToggleKeywordHide",
					order = 2
				},
				spacer2 = {
					name = "",			
					type = "description",
					order = 3,
				},
				unitLoot = {
					name = "Autoloot",
					desc = "Skinning mode will pick up and delete any items left over after autolooting.\n|cFFFF0000(WARNING: use with caution this deletes items. HL is not responsible for lost items.)",
					type = "toggle",
					set = "SetUnitLoot",
					get = "GetUnitLoot",
					order = 4
				},
				unitClose = {
					name = "Autoclose",
					desc = "Skinning mode will pick up and delete any items left over after autolooting.\n|cFFFF0000(WARNING: use with caution this deletes items. HL is not responsible for lost items.)",
					type = "toggle",
					set = "SetUnitClose",
					get = "GetUnitClose",
					order = 5
				},
			},
		},
		groupHelp = {
			name = L["HelpGroup"],
			type = "group",
			childGroups = "select",
			order = 16,
			args = {
				desc = {
					name = L["HelpDesc"],
					type = "description",
					order = 0,
				},
				groupSys = {
					name = L["SysHelpGroup"],
					type = "group",
					order = 1,
					args = {
						desc = {
							name = MakeColor("ctrl", L["ACGroup"])..L["SysHelp1"]..MakeColor("ctrl", L["SkinningGroup"])..L["SysHelp2"],			
							type = "description",
							order = 1,
						},
					},
				},
				groupLM = {
					name = L["LootMonGroup"],
					type = "group",
					order = 2,
					args = {
						desc = {
							name = MakeColor("ctrl", L["Themes"])..L["LMHelp1"]..MakeColor("ctrl", L["GridModeGroup"])..L["LMHelp2"],			
							type = "description",
							order = 1,
						},
					},
				},
				groupIQ = {
					name = L["ItemQualityGroup"],
					type = "group",
					order = 3,
					args = {
						desc = {
							name = L["IQHelp1"]..MakeColor("ctrl", L["PoorFilterName"])..L["IQHelp2"],			
							type = "description",
							order = 1,
						},
					},
				},
				groupIE = {
					name = L["IEListHelpGroup"],
					type = "group",
					order = 4,
					hidden = false,
					args = {
						desc = {
							name = MakeColor("ctrl", L["IEListHelpGroup"])..L["IEListHelp1"],			
							type = "description",
							order = 1,
						},
					},
				},
				groupThresh = {
					name = L["ThreshGroup"],
					type = "group",
					order = 5,
					args = {
						desc = {
							name = MakeColor("ctrl", L["Thresh1TypeName"])..L["ThreshHelp1"]..MakeColor("ctrl", L["Thresh1ValueName"])..L["ThreshHelp2"]..MakeColor("ctrl", L["UseQuantValName"])..L["ThreshHelp3"],			
							type = "description",
							order = 1,
						},
					},
				},
				groupSC = {
					name = L["SCHelpGroup"],
					type = "group",
					order = 6,
					args = {
						desc = {
							name = L["SCHelp1"],
							type = "description",
							order = 1,
						},
					},
				},
			},
		},
		groupAbout = {
			name = "About",
			type = "group",
			order = 17,
			args = {
				spacer2 = {
					name = "HotLoot v"..GetAddOnMetadata("HotLoot", "Version").." ©2013\nAuthor: Neil Smith\nCo-author: Jessica Mitchell\nTranslations:\nphilipp5796 - German\nCurse: http://www.curse.com/addons/wow/hotloot\n\nMore About info coming soon.",			
					type = "description",
					order = 1,
				},
			},
		},
    },
}



-- Config Defaults
hlDefaults = {
	char = {
		minimap = {
			hide = false,
			minimapPos = 270
		},
		lootEnabled = true,
		lootDebug = false,
		lootAnnounce = true,
		lootAdvanced = false,
		lootClose = false,
		lootCloseKey = "0",
		lootSkinMode = false,
		lootSkinKey = "0", 
		lootEnableMonitor = true,
		lootShowAnchor = true,
		lootShowNames = true, 
		lootShowQuantities = true, 
		lootIconSize = 16, 
		lootTransparency = 1,
		inlineQuant = true,
		lootShowTotal = true,
		lootGrowthDirection = -1, 
		textSide = 0,
		themeSelect = "classic",
		minWidth = "145",
		initialDelay = 5,
		secondaryDelay = 1,
		fadeSpeed = 5,
		themeColorR = 0,
		themeColorG = 1,
		themeColorB = 1,
		lootGridMode = false,
		lootGridNumColumns = 4,
		lootGold = true,
		lootQuest = true,
		lootJunk = false,
		lootJunkDel = false,
		lootCloth = false,
		lootMining = false,
		lootGems = false,
		lootHerbs = false,
		lootSkinning = false,
		lootFishing = false,
		lootEnchanting = false,
		lootCooking = false,
		lootRecipes = false,
		lootPots = false,
		lootFlasks = false,
		lootElixirs = false,
		lootMoH = false,
		lootElemental = false,
		lootSetLootCurrency = false,
		lootBotA = true,
		lootDoEM = true,
		lootSC = true,
		lootPoor = false,
		lootCommon = false,
		lootUncommon = true,
		lootRare = true,
		lootEpic = true,
		lootCustom = false,
		eList = { },
		iList = { },
		useQuant = false,
	}
}


--#############################
-- 		Set/Get Functions
--#############################
-- lootEnabled
function HotLoot:SetLootEnabled(info, value)
	self.db.char.lootEnabled = value;
	dBug("lootEnabled", value);
end
function HotLoot:GetLootEnabled(info)
	return self.db.char.lootEnabled;
end

-- lootEnableMonitor
function HotLoot:SetLootEnableMonitor(info, value)
	self.db.char.lootEnableMonitor = value;
	dBug("lootEnableMonitor", value);
end
function HotLoot:GetLootEnableMonitor(info)
	return self.db.char.lootEnableMonitor;
end

-- lootShowAnchor
function HotLoot:SetLootShowAnchor(info, value)
	self.db.char.lootShowAnchor = value;
	dBug("lootShowAnchor", value);
	HotLoot:ToggleAnchor(value);
end
function HotLoot:GetLootShowAnchor(info)
	return self.db.char.lootShowAnchor;
end

-- lootShowNames
function HotLoot:SetLootShowNames(info, value)
	self.db.char.lootShowNames = value;
	dBug("lootShowNames", value);
end
function HotLoot:GetLootShowNames(info)
	return self.db.char.lootShowNames;
end

-- lootShowQuantities
function HotLoot:SetLootShowQuantities(info, value)
	self.db.char.lootShowQuantities = value;
	dBug("lootShowQuantities", value);
end
function HotLoot:GetLootShowQuantities(info)
	return self.db.char.lootShowQuantities;
end

-- HotLoot:GetShowTotal()
function HotLoot:SetShowTotal(info, value)
	self.db.char.lootShowTotal = value
	dBug("lootShowTotal", value)
end
function HotLoot:GetShowTotal(info)
	return self.db.char.lootShowTotal
end

-- lootIconSize
function HotLoot:SetLootIconSize(info, value)
	self.db.char.lootIconSize = value;
	dBug("lootIconSize", value);
end
function HotLoot:GetLootIconSize(info)
	return self.db.char.lootIconSize;
end

-- SetLootTrans
function HotLoot:SetLootTrans(info, value)
	self.db.char.lootTrans = value;
	dBug("lootTrans", value);
end
function HotLoot:GetLootTrans(info)
	return self.db.char.lootTrans;
end

-- lootGrowthDirection
function HotLoot:SetLootGrowthDirection(info, value)
	self.db.char.lootGrowthDirection = value;
	dBug("lootGrowthDirection", value);
end
function HotLoot:GetLootGrowthDirection(info)
	return self.db.char.lootGrowthDirection;
end

-- HotLoot:GetTextSide()
function HotLoot:SetTextSide(info, value)
	self.db.char.textSide = value;
	dBug("textSide", value);
end
function HotLoot:GetTextSide(info)
	return self.db.char.textSide;
end

-- SetInlineQuant
function HotLoot:SetInlineQuant(info, value)
	self.db.char.inlineQuant = value;
	dBug("inlineQuant", value);
end
function HotLoot:GetInlineQuant(info)
	return self.db.char.inlineQuant;
end

-- HotLoot:GetThemeSelect()
function HotLoot:SetThemeSelect(info, value)
	self.db.char.themeSelect = value;
	dBug("themeSelect", value);
	LoadTheme(value);
end
function HotLoot:GetThemeSelect(info)
	return self.db.char.themeSelect;
end

-- HotLoot:GetColorQual()
function HotLoot:SetColorQual(info, value)
	self.db.char.colorQual = value;
	dBug("GetColorQual", value);
end
function HotLoot:GetColorQual(info)
	return self.db.char.colorQual;
end
-- LoadTheme(HotLoot:GetThemeSelect());
-- SetThemeColor
function HotLoot:SetThemeColorSelect(info, r, g, b, a)
	self.db.char.themeColorR = r;
	self.db.char.themeColorG = g;
	self.db.char.themeColorB = b;
	self.db.char.themeColorA = a;
	dBug("themeColor", r..", "..g..", "..b..", "..a);
end
function HotLoot:GetThemeColorSelect(info)
	return self.db.char.themeColorR, self.db.char.themeColorG, self.db.char.themeColorB, self.db.char.themeColorA;
end

function HotLoot:SetThemeColorBorderSelect(info, r, g, b, a)
	self.db.char.themeColorBorderR = r;
	self.db.char.themeColorBorderG = g;
	self.db.char.themeColorBorderB = b;
	self.db.char.themeColorBorderA = a;
	dBug("themeColor", r..", "..g..", "..b..", "..a);
end
function HotLoot:GetThemeColorBorderSelect(info)
	return self.db.char.themeColorBorderR, self.db.char.themeColorBorderG, self.db.char.themeColorBorderB, self.db.char.themeColorBorderA;
end

function HotLoot:ToggleThemeColorHide()
	local tc = HotLoot:GetThemeSelect();
	if tc == 2 then
		--HotLoot:SetLootGridMode(false);
		return false;
	else
		return true;
	end
end

-- minWidth
function HotLoot:SetMinWidth(info, value)
	self.db.char.minWidth = value;
	dBug("minWidth", value);
end
function HotLoot:GetMinWidth(info)
	return self.db.char.minWidth;
end

-- iDelay
function HotLoot:SetIDelay(info, value)
	self.db.char.initialDelay = value;
	dBug("initialDelay", value);
end
function HotLoot:GetIDelay(info)
	return self.db.char.initialDelay;
end

-- sDelay
function HotLoot:SetSDelay(info, value)
	self.db.char.secondaryDelay = value;
	dBug("secondaryDelay", value);
end
function HotLoot:GetSDelay(info)
	return self.db.char.secondaryDelay;
end

-- fSpeed
function HotLoot:SetFSpeed(info, value)
	self.db.char.fadeSpeed = value;
	dBug("fadeSpeed", value);
end
function HotLoot:GetFSpeed(info)
	return self.db.char.fadeSpeed;
end

-- lootGridMode
function HotLoot:SetLootGridMode(info, value)
	self.db.char.lootGridMode = value;
	dBug("lootGridMode", value);
end
function HotLoot:GetLootGridMode(info)
	return self.db.char.lootGridMode;
end

function HotLoot:ToggleGridDisable()
	local namesChecked = HotLoot:GetLootShowNames();
	if namesChecked == true then
		--self.options.args.goupLootMonitor.lootGridMode:SetDisabled(true);
		HotLoot:SetLootGridMode(false);
		return true;
	else
		--self.options.args.goupLootMonitor.lootGridMode:SetDisabled(false);
		return false;
	end
end


-- lootGridNumColumns
function HotLoot:SetLootGridNumColumns(info, value)
	self.db.char.lootGridNumColumns = value;
	dBug("lootGridNumColumns", value);
end
function HotLoot:GetLootGridNumColumns(info)
	return self.db.char.lootGridNumColumns;
end



-- ResetMonitor
function HotLoot:ResetMonitor()
	HotLoot.mainFrame:ClearAllPoints();
	HotLoot.mainFrame:SetPoint("CENTER", 0, 0);
	--HotLoot:UpdateMonitor();
	Announce("Anchor position reset.");
end

-- lootGold
function HotLoot:SetLootGold(info, value)
	self.db.char.lootGold = value;
	dBug("lootGold", value);
end
function HotLoot:GetLootGold(info)
	return self.db.char.lootGold;
end

-- lootQuest
function HotLoot:SetLootQuest(info, value)
	self.db.char.lootQuest = value;
	dBug("lootQuest", value);
end
function HotLoot:GetLootQuest(info)
	return self.db.char.lootQuest;
end

-- lootJunk
function HotLoot:SetLootJunk(info, value)
	self.db.char.lootJunk = value;
	dBug("lootJunk", value);
end
function HotLoot:GetLootJunk(info)
	return self.db.char.lootJunk;
end

-- lootJunkDel
function HotLoot:SetLootJunkDel(info, value)
	self.db.char.lootJunkDel = value;
	dBug("lootJunkDel", value);
end
function HotLoot:GetLootJunkDel(info)
	return self.db.char.lootJunkDel;
end

-- SetUnitEnable	SetTypeSelect	SetUnitKeyword	SetUnitLoot	SetUnitClose

function HotLoot:SetUnitEnable(info, value)
	self.db.char.unitEnable = value;
	dBug("GetUnitEnable", value);
end
function HotLoot:GetUnitEnable(info)
	return self.db.char.unitEnable;
end

function HotLoot:SetTypeSelect(info, key, value)
	self.db.char[key] = value;
	dBug(key, value);
end
function HotLoot:GetTypeSelect(info, key)
	return self.db.char[key];
end

function HotLoot:SetUnitKeyword(info, value)
	self.db.char.unitKeyword = value;
	dBug("UnitKeyword", value);
end
function HotLoot:GetUnitKeyword(info)
	return self.db.char.unitKeyword;
end

function HotLoot:ToggleKeywordHide()
	local uk = HotLoot:GetTypeSelect(nil,"unitKeyword");
	if uk == true then
		--HotLoot:SetLootGridMode(false);
		return false;
	else
		return true;
	end
end

function HotLoot:SetUnitLoot(info, value)
	self.db.char.unitLoot = value;
	dBug("UnitLoot", value);
end
function HotLoot:GetUnitLoot(info)
	return self.db.char.unitLoot;
end

function HotLoot:SetUnitClose(info, value)
	self.db.char.unitClose = value;
	dBug("UnitClose", value);
end
function HotLoot:GetUnitClose(info)
	return self.db.char.unitClose;
end

-- lootDebug
function HotLoot:SetLootDebug(info, value)
	self.db.char.lootDebug = value;
	dBug("lootDebug", value);
end
function HotLoot:GetLootDebug(info)
	return self.db.char.lootDebug;
end

--lootAnnounce
function HotLoot:SetLootAnnounce(info, value)
	self.db.char.lootAnnounce = value;
	dBug("lootAnnounce", value);
end
function HotLoot:GetLootAnnounce(info)
	return self.db.char.lootAnnounce;
end

--Minimap
function HotLoot:SetMinimap(info, value)
	self.db.char.minimap.hide = value;
	dBug("minimap.hide", value);
	if value then
		hIcon:Hide("HotLoot")
	elseif not value then
		hIcon:Show("HotLoot")
	end
end
function HotLoot:GetMinimap(info)
	return self.db.char.minimap.hide;
end

--SetLootAdvanced
function HotLoot:SetLootAdvanced(info, value)
	self.db.char.lootAdvanced = value;
	dBug("lootAdvanced", value);
end
function HotLoot:GetLootAdvanced(info)
	return self.db.char.lootAdvanced;
end

function HotLoot:Advanced()
	if HotLoot:GetLootAdvanced() then
		return false;
	else
		return true;
	end
end

-- lootClose
function HotLoot:SetLootClose(info, value)
	self.db.char.lootClose = value;
	dBug("lootClose", value);
end
function HotLoot:GetLootClose(info)
	return self.db.char.lootClose;
end

-- lootCloseKey
function HotLoot:SetLootCloseKey(info, value)
	self.db.char.lootCloseKey = value;
	dBug("lootCloseKey", value);
end
function HotLoot:GetLootCloseKey(info)
	return self.db.char.lootCloseKey;
end

-- lootSkinKey
function HotLoot:SetLootSkinKey(info, value)
	self.db.char.lootSkinKey = value;
	dBug("lootSkinKey", value);
end
function HotLoot:GetLootSkinKey(info)
	return self.db.char.lootSkinKey;
end

-- lootSkinMode
function HotLoot:SetLootSkinMode(info, value)
	self.db.char.lootSkinMode = value;
	dBug("lootSkinMode", value);
end
function HotLoot:GetLootSkinMode(info)
	return self.db.char.lootSkinMode;
end

--lootCloth
function HotLoot:SetLootCloth(info, value)
	self.db.char.lootCloth = value;
	dBug("lootCloth", value);
end
function HotLoot:GetLootCloth(info)
	return self.db.char.lootCloth;
end

--lootMining
function HotLoot:SetLootMining(info, value)
	self.db.char.lootMining = value;
	dBug("lootMining", value);
end
function HotLoot:GetLootMining(info)
	return self.db.char.lootMining;
end

--lootOre
--[[function HotLoot:SetLootOre(info, value)
	self.db.char.lootOre = value;
	dBug("lootOre", value);
end
function HotLoot:GetLootOre(info)
	return self.db.char.lootOre;
end

--lootStone
function HotLoot:SetLootStone(info, value)
	self.db.char.lootStone = value;
	dBug("lootStone", value);
end
function HotLoot:GetLootStone(info)
	return self.db.char.lootStone;
end
]]
--lootGems
function HotLoot:SetLootGems(info, value)
	self.db.char.lootGems = value;
	dBug("lootGems", value);
end
function HotLoot:GetLootGems(info)
	return self.db.char.lootGems;
end

--lootHerbs
function HotLoot:SetLootHerbs(info, value)
	self.db.char.lootHerbs = value;
	dBug("lootHerbs", value);
end
function HotLoot:GetLootHerbs(info)
	return self.db.char.lootHerbs;
end

--lootSkinning
function HotLoot:SetLootSkinning(info, value)
	self.db.char.lootSkinning = value;
	dBug("lootSkinning", value);
end
function HotLoot:GetLootSkinning(info)
	return self.db.char.lootSkinning;
end

-- lootFishing
function HotLoot:SetLootFishing(info, value)
	self.db.char.lootFishing = value;
	dBug("lootFishing", value);
end
function HotLoot:GetLootFishing(info)
	return self.db.char.lootFishing;
end

-- lootEnchanting
function HotLoot:SetLootEnchanting(info, value)
	self.db.char.lootEnchanting = value;
	dBug("lootEnchanting", value);
end
function HotLoot:GetLootEnchanting(info)
	return self.db.char.lootEnchanting;
end

-- lootCooking
function HotLoot:SetLootCooking(info, value)
	self.db.char.lootCooking = value;
	dBug("lootCooking", value);
end
function HotLoot:GetLootCooking(info)
	return self.db.char.lootCooking;
end

--SetLootRecipes
function HotLoot:SetLootRecipes(info, value)
	self.db.char.lootRecipes = value;
	dBug("lootRecipes", value);
end
function HotLoot:GetLootRecipes(info)
	return self.db.char.lootRecipes;
end

-- lootPots
function HotLoot:SetLootPots(info, value)
	self.db.char.lootPots = value;
	dBug("lootPots", value);
end
function HotLoot:GetLootPots(info)
	return self.db.char.lootPots;
end

-- lootFlasks
function HotLoot:SetLootFlasks(info, value)
	self.db.char.lootFlasks = value;
	dBug("lootFlasks", value);
end
function HotLoot:GetLootFlasks(info)
	return self.db.char.lootFlasks;
end

-- lootElixirs
function HotLoot:SetLootElixirs(info, value)
	self.db.char.lootElixirs = value;
	dBug("lootElixirs", value);
end
function HotLoot:GetLootElixirs(info)
	return self.db.char.lootElixirs;
end

-- lootMoH
function HotLoot:SetLootMoH(info, value)
	self.db.char.lootMoH = value;
	dBug("lootMoH", value);
end
function HotLoot:GetLootMoH(info)
	return self.db.char.lootMoH;
end

-- excludeList
function HotLoot:SetExcludeList(info, value)
	--self.db.char.excludeList = value
	dBug("excludeList", value)
	AddEList(value)
end
function HotLoot:GetExcludeList(info)
	--return self.db.char.includeList;
end

function HotLoot:SetExcludeDrop(info, value)
	self.db.char.excludeDrop = value
	dBug("excludeDrop", value)
end
function HotLoot:GetExcludeDrop(info)
	return self.db.char.excludeDrop;
end

-- includeList
function HotLoot:SetIncludeList(info, value)
	--self.db.char.includeList = value
	dBug("includeList", value)
	AddIList(value)
end
function HotLoot:GetIncludeList(info)
	--return self.db.char.includeList;
end

function HotLoot:SetIncludeDrop(info, value)
	self.db.char.includeDrop = value
	dBug("includeDrop", value)
end
function HotLoot:GetIncludeDrop(info)
	return self.db.char.includeDrop;
end

-- SetLootElemental
function HotLoot:SetLootElemental(info, value)
	self.db.char.lootElemental = value;
	dBug("lootElemental", value);
end
function HotLoot:GetLootElemental(info)
	return self.db.char.lootElemental;
end

--SetLootBotA
function HotLoot:SetLootBotA(info, value)
	self.db.char.lootBotA = value;
	dBug("lootBotA", value);
end
function HotLoot:GetLootBotA(info)
	return self.db.char.lootBotA;
end

--SetLootDoEM
function HotLoot:SetLootDoEM(info, value)
	self.db.char.lootDoEM = value;
	dBug("lootDoEM", value);
end
function HotLoot:GetLootDoEM(info)
	return self.db.char.lootDoEM;
end

--SetLootSC
function HotLoot:SetLootSC(info, value)
	self.db.char.lootSC = value;
	dBug("lootSC", value);
end
function HotLoot:GetLootSC(info)
	return self.db.char.lootSC;
end

--SetLootRepMeat
function HotLoot:SetLootRepMeat(info, value)
	self.db.char.lootRepMeat = value;
	dBug("lootRepMeat", value);
end
function HotLoot:GetLootRepMeat(info)
	return self.db.char.lootRepMeat;
end

--lootPoor
function HotLoot:SetLootPoor(info, value)
	self.db.char.lootPoor = value;
	dBug("lootPoor", value);
end
function HotLoot:GetLootPoor(info)
	return self.db.char.lootPoor;
end

--lootCommon
function HotLoot:SetLootCommon(info, value)
	self.db.char.lootCommon = value;
	dBug("lootCommon", value);
end
function HotLoot:GetLootCommon(info)
	return self.db.char.lootCommon;
end

--lootUncommon
function HotLoot:SetLootUncommon(info, value)
	self.db.char.lootUncommon = value;
	dBug("lootUncommon", value);
end
function HotLoot:GetLootUncommon(info)
	return self.db.char.lootUncommon;
end

--lootRare
function HotLoot:SetLootRare(info, value)
	self.db.char.lootRare = value;
	dBug("lootRare", value);
end
function HotLoot:GetLootRare(info)
	return self.db.char.lootRare;
end

--lootEpic
function HotLoot:SetLootEpic(info, value)
	self.db.char.lootEpic = value;
	dBug("lootEpic", value);
end
function HotLoot:GetLootEpic(info)
	return self.db.char.lootEpic;
end

--lootLegendary
function HotLoot:SetLootLegendary(info, value)
	self.db.char.lootLegendary = value;
	dBug("lootLegendary", value);
end
function HotLoot:GetLootLegendary(info)
	return self.db.char.lootLegendary;
end

--lootCurrency
function HotLoot:SetLootCurrency(info, value)
	self.db.char.lootCurrency = value;
	dBug("lootCurrency", value);
end
function HotLoot:GetLootCurrency(info)
	return self.db.char.lootCurrency;
end
function ToCopper(input)
	local gold = tonumber(string.match(input,"(%d+)%s?[gG]")) or 0;
	local silver = tonumber(string.match(input,"(%d+)%s?[sS]")) or 0;
	local copper = tonumber(string.match(input,"(%d+)%s?[cC]")) or 0;
	local total = (gold*10000)+(silver*100)+(copper);
	return total;
end

--type1 
function HotLoot:SetType1(info, value)
	self.db.char.type1 = value;
	dBug("type1", value);
end
function HotLoot:GetType1(info)
	return self.db.char.type1;
end

--value1
function HotLoot:SetValue1(info, value)
	self.db.char.value1 = value;
	dBug("value1 to copper", tonumber(ToCopper(value)));
end

function HotLoot:GetValue1(info)
	return self.db.char.value1;
end

--type2
function HotLoot:SetType2(info, value)
	self.db.char.type2 = value;
	dBug("type2", value);
end
function HotLoot:GetType2(info)
	return self.db.char.type2;
end

--value2
function HotLoot:SetValue2(info, value)
	self.db.char.value2 = value;
	dBug("value2", value);
end
function HotLoot:GetValue2(info)
	return self.db.char.value2;
end

--type3
function HotLoot:SetType3(info, value)
	self.db.char.type3 = value;
	dBug("type3", value);
end
function HotLoot:GetType3(info)
	return self.db.char.type3;
end

--value3
function HotLoot:SetValue3(info, value)
	self.db.char.value3 = value;
	dBug("value3", value);
end
function HotLoot:GetValue3(info)
	return self.db.char.value3;
end

-- useQuant
function HotLoot:SetUseQuant(info, value)
	self.db.char.useQuant = value;
	dBug("useQuant", value);
end
function HotLoot:GetUseQuant(info)
	return self.db.char.useQuant;
end
